from simplepipeline.task import task, filter_task, set_pipeline, get_pipeline, delete_pipeline
from simplepipeline.map.parallel import par_map, par_map_unpack
from simplepipeline.map.sequential import seq_map, seq_map_unpack
from simplepipeline.pipeline import Pipeline
